@@ -1,4 +1,3 @@
 from autolens.pipeline.phase.dataset.analysis import Analysis
-from autolens.pipeline.phase.dataset.meta_dataset import MetaDataset
+from autolens.pipeline.phase.dataset.meta_dataset import MetaLens
 from autolens.pipeline.phase.dataset.result import Result
-from .phase import PhaseDataset
