@@ -1,9 +1,8 @@
-from astropy import cosmology as cosmo
-
 import autofit as af
-from autoastro.galaxy import fit_galaxy
-from autoastro.galaxy import masked_galaxy_data
-from autolens.pipeline.phase import abstract
+from astropy import cosmology as cosmo
+from autogalaxy.galaxy import fit_galaxy
+from autogalaxy.galaxy import masked_galaxy_data
+from autogalaxy.pipeline.phase import abstract
 from autolens.pipeline import visualizer
 
 
@@ -21,7 +20,7 @@ class AnalysisSingle(Analysis):
 
         self.galaxy_data = galaxy_data
 
-    def fit(self, instance):
+    def log_likelihood_function(self, instance):
         fit = self.fit_for_instance(instance=instance)
         return fit.figure_of_merit
 
@@ -77,7 +76,7 @@ class AnalysisDeflections(Analysis):
         self.galaxy_data_y = galaxy_data_y
         self.galaxy_data_x = galaxy_data_x
 
-    def fit(self, instance):
+    def log_likelihood_function(self, instance):
         fit_y, fit_x = self.fit_for_instance(instance=instance)
         return fit_y.figure_of_merit + fit_x.figure_of_merit
 
@@ -131,33 +130,31 @@ class PhaseGalaxy(abstract.AbstractPhase):
     def __init__(
         self,
         phase_name,
-        phase_folders=tuple(),
+        search,
+        folders=tuple(),
         galaxies=None,
         use_image=False,
         use_convergence=False,
         use_potential=False,
         use_deflections=False,
-        non_linear_class=af.MultiNest,
         sub_size=2,
-        pixel_scale_interpolation_grid=None,
+        pixel_scales_interp=None,
         cosmology=cosmo.Planck15,
     ):
         """
-        A phase in an lens pipeline. Uses the set non_linear optimizer to try to fit
+        A phase in an lens pipeline. Uses the set non_linear search to try to fit
         models and hyper_galaxies passed to it.
 
         Parameters
         ----------
-        non_linear_class: class
-            The class of a non_linear optimizer
+        search: class
+            The class of a non_linear search
         sub_size: int
             The side length of the subgrid
         """
 
         super(PhaseGalaxy, self).__init__(
-            phase_name=phase_name,
-            phase_folders=phase_folders,
-            non_linear_class=non_linear_class,
+            phase_name=phase_name, folders=folders, search=search
         )
         self.cosmology = cosmology
         self.use_image = use_image
@@ -166,9 +163,9 @@ class PhaseGalaxy(abstract.AbstractPhase):
         self.use_deflections = use_deflections
         self.galaxies = galaxies
         self.sub_size = sub_size
-        self.pixel_scale_interpolation_grid = pixel_scale_interpolation_grid
+        self.pixel_scales_interp = pixel_scales_interp
 
-    def run(self, galaxy_data, mask, results=None):
+    def run(self, galaxy_data, mask, info=None, results=None):
         """
         Run this phase.
 
@@ -192,10 +189,8 @@ class PhaseGalaxy(abstract.AbstractPhase):
 
         self.save_metadata(galaxy_data.name)
         self.model = self.model.populate(results)
-        self.customize_priors(results)
-        self.assert_and_save_pickle()
 
-        result = self.run_analysis(analysis)
+        result = self.run_analysis(analysis=analysis, info=info)
 
         return self.make_result(result, analysis)
 
@@ -215,7 +210,7 @@ class PhaseGalaxy(abstract.AbstractPhase):
         Returns
         -------
         lens: Analysis
-            An lens object that the non-linear optimizer calls to determine the fit of a
+            An lens object that the non-linear search calls to determine the fit of a
              set of values
         """
 
@@ -224,7 +219,7 @@ class PhaseGalaxy(abstract.AbstractPhase):
             galaxy_data = masked_galaxy_data.MaskedGalaxyDataset(
                 galaxy_data=galaxy_data[0],
                 mask=mask,
-                pixel_scale_interpolation_grid=self.pixel_scale_interpolation_grid,
+                pixel_scales_interp=self.pixel_scales_interp,
                 use_image=self.use_image,
                 use_convergence=self.use_convergence,
                 use_potential=self.use_potential,
@@ -235,7 +230,7 @@ class PhaseGalaxy(abstract.AbstractPhase):
             return AnalysisSingle(
                 galaxy_data=galaxy_data,
                 cosmology=self.cosmology,
-                image_path=self.optimizer.paths.image_path,
+                image_path=self.search.paths.image_path,
                 results=results,
             )
 
@@ -244,7 +239,7 @@ class PhaseGalaxy(abstract.AbstractPhase):
             galaxy_data_y = masked_galaxy_data.MaskedGalaxyDataset(
                 galaxy_data=galaxy_data[0],
                 mask=mask,
-                pixel_scale_interpolation_grid=self.pixel_scale_interpolation_grid,
+                pixel_scales_interp=self.pixel_scales_interp,
                 use_image=self.use_image,
                 use_convergence=self.use_convergence,
                 use_potential=self.use_potential,
@@ -255,7 +250,7 @@ class PhaseGalaxy(abstract.AbstractPhase):
             galaxy_data_x = masked_galaxy_data.MaskedGalaxyDataset(
                 galaxy_data=galaxy_data[1],
                 mask=mask,
-                pixel_scale_interpolation_grid=self.pixel_scale_interpolation_grid,
+                pixel_scales_interp=self.pixel_scales_interp,
                 use_image=self.use_image,
                 use_convergence=self.use_convergence,
                 use_potential=self.use_potential,
@@ -267,7 +262,7 @@ class PhaseGalaxy(abstract.AbstractPhase):
                 galaxy_data_y=galaxy_data_y,
                 galaxy_data_x=galaxy_data_x,
                 cosmology=self.cosmology,
-                image_path=self.optimizer.paths.image_path,
+                image_path=self.search.paths.image_path,
                 results=results,
             )
 
