@@ -8,11 +8,11 @@ data_name = "lens_sie__source_smooth"
 instrument = "vro"
 
 
-def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
+def make_pipeline(name, folders, search=af.DynestyStatic()):
 
     phase1 = al.PhaseImaging(
         phase_name="phase_1",
-        folders=setup.folders,
+        folders=folders,
         galaxies=dict(
             lens=al.GalaxyModel(
                 redshift=0.5,
@@ -21,14 +21,9 @@ def make_pipeline(name, folders, search=af.PySwarmsGlobal()):
             ),
             source=al.GalaxyModel(redshift=1.0, light=al.lp.EllipticalSersic),
         ),
-        sub_size=8,
         search=search,
     )
 
-    phase1.search.const_efficiency_mode = True
-    phase1.search.n_live_points = 60
-    phase1.search.sampling_efficiency = 0.8
-
     return al.PipelineDataset(name, phase1)
 
 
