@@ -1,5 +1,6 @@
-from autolens.fit.plotters import masked_imaging_fit_plotters
-from test import simulate_util
+import autolens as al
+import autolens.plot as aplt
+from test_autolens.simulate.imaging import simulate_util
 
 # In this tutorial, we'll introduce a new pixelization, called an adaptive-pixelization. This pixelization doesn't use
 # uniform grid of rectangular pixels, but instead uses ir'Voronoi' pixels. So, why would we want to do that?
@@ -7,22 +8,27 @@ from test import simulate_util
 
 # Lets quickly remind ourselves of the image, and the 3.0" circular mask we'll use to mask it.
 imaging = simulate_util.load_test_imaging(
-    data_type="lens_light_dev_vaucouleurs", data_resolution="lsst"
+    data_name="lens_light_dev_vaucouleurs", instrument="vro"
 )
+
 mask = al.Mask.circular(
-    shape_2d=imaging.shape_2d, pixel_scales=imaging.pixel_scales, radius=3.0
+    shape_2d=imaging.shape_2d,
+    pixel_scales=imaging.pixel_scales,
+    radius=3.0,
+    centre=(3.0, 3.0),
 )
 
 # The lines of code below do everything we're used to, that is, setup an image and its grid, mask it, trace it
 # via a tracer, setup the rectangular mapper, etc.
 lens_galaxy = al.Galaxy(
-    bulge=al.EllipticalDevVaucouleurs(
+    redshift=0.5,
+    light=al.lp.EllipticalDevVaucouleurs(
         centre=(0.0, 0.0), axis_ratio=0.9, phi=45.0, intensity=0.1, effective_radius=1.0
-    )
+    ),
 )
 
 masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
 tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy])
 fit = al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
-aplt_array.fit_imaging.subplot_imaging(fit=fit, mask=True)
+aplt.FitImaging.subplot_fit_imaging(fit=fit)
